feapi

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 31, 2023 License: MIT Imports: 16 Imported by: 0

README

feapi

Front-end optimized APIs

APIs in here must not make use of the database or any element not available to the platform-fe project. Those APIs are aiming at providing edge-optimized processing speed.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Handle

func Handle(ctx context.Context, path, verb string) (any, error)

Types

type Country

type Country countrydb.Country

func (Country) Export

func (country Country) Export(curlng language.Tag) map[string]any

func (Country) MarshalJSON

func (country Country) MarshalJSON() ([]byte, error)

type Language

type Language lngdb.Lng

func (Language) MarshalJSON

func (ln Language) MarshalJSON() ([]byte, error)

type LanguagesSort

type LanguagesSort []*Language

func (LanguagesSort) Bytes

func (l LanguagesSort) Bytes(i int) []byte

func (LanguagesSort) Len

func (l LanguagesSort) Len() int

func (LanguagesSort) Swap

func (l LanguagesSort) Swap(i, j int)

type Sortable

type Sortable []*SortableValue

func (Sortable) Len

func (s Sortable) Len() int

func (Sortable) Less

func (s Sortable) Less(i, j int) bool

func (Sortable) Swap

func (s Sortable) Swap(i, j int)

type SortableValue

type SortableValue struct {
	V any
	K []byte
}

func (*SortableValue) MarshalJSON

func (s *SortableValue) MarshalJSON() ([]byte, error)

Jump to